@@ -1,32 +1,28 @@
 /*
- *  SA - Socket Address Library
- *  Copyright (c) 2001 The OSSP Project (http://www.ossp.org/)
- *  Copyright (c) 2001 Cable & Wireless Deutschland (http://www.cw.com/de/)
- *
- *  This file is part of OSSP lmtp2nntp, an LMTP speaking local
- *  mailer which forwards mails as Usenet news articles via NNTP.
- *  It can be found at http://www.ossp.com/pkg/lmtp2nntp/.
- *
- *  Permission to use, copy, modify, and distribute this software for
- *  any purpose with or without fee is hereby granted, provided that
- *  the above copyright notice and this permission notice appear in all
- *  copies.
- *
- *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
- *  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- *  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
- *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- *  SUCH DAMAGE.
- *
- *  sa.c: implementation
- */
+**  Copyright (c) 2001 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001 Cable & Wireless Deutschland <http://www.cw.com/de/>
+**
+**  This file is part of OSSP lmtp2nntp, an LMTP speaking local
+**  mailer which forwards mails as Usenet news articles via NNTP.
+**  It can be found at http://www.ossp.org/pkg/lmtp2nntp/.
+**
+**  This program is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU General Public  License
+**  as published by the Free Software Foundation; either version
+**  2.0 of the License, or (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+**  General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this file; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+**  USA, or contact the OSSP project <ossp@ossp.org>.
+**
+**  sa.c: Socket Address library
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -114,6 +110,7 @@ sa_t *sa_create(int sa_type, ...)
         if ((nPath = strlen(cpPath)) >= (sizeof(sau.sun_path)-1))
             return NULL;
         nProto = 0;
+        memset(&sau, 0, sizeof(sau));
         sau.sun_family = AF_LOCAL;
         memcpy(sau.sun_path, cpPath, nPath + 1);
         sa = (struct sockaddr *)&sau;
@@ -151,6 +148,11 @@ sa_t *sa_create(int sa_type, ...)
             nPort = ntohs(se->s_port);
         }
 
+        /* mandatory initialization */
+        memset(&sa4, 0, sizeof(sa4));
+#ifdef AF_INET6
+        memset(&sa6, 0, sizeof(sa6));
+#endif
         /* resolve host */
         if (inet_pton(AF_INET, cpHost, &sa4.sin_addr.s_addr) == 1) {
             sa4.sin_family = AF_INET;
